@@ -128,6 +128,54 @@ class AppController():
         ssh_cmd = ['ssh', '-t'] + sshopts + ['-p', SSH_FORWARDER_PORT, '--', user_host, command]
         subprocess.call(ssh_cmd)
 
+    def rollback_cmd(self, args):
+        """
+           Rollback command
+        """
+
+        try:
+            app_name, deployment_name = self.parse_app_deployment_name(args.name)
+        except ParseAppDeploymentName:
+            raise InputErrorException('InvalidApplicationName')
+
+        if deployment_name == '':
+            raise InputErrorException('NoDeployment')
+
+        logEntries = []
+
+        try:
+            logEntries = self.api.read_log(
+                app_name,
+                deployment_name,
+                'deploy',
+                last_time=None)
+        except GoneError:
+            raise InputErrorException('WrongApplication')
+
+        deployments = [e['message'].split(':')[1].strip() for e in logEntries
+                       if 'Deployed version' in e['message']]
+
+        current_deployment = deployments.pop()
+        previous_deployment = None
+
+        while not previous_deployment:
+            try:
+                deployment_version = deployments.pop()
+                if deployment_version != current_deployment:
+                    previous_deployment = deployment_version
+            except IndexError:
+                raise InputErrorException('NoPreviousVersionFound')
+
+        try:
+            self.api.update_deployment(
+                app_name,
+                version=previous_deployment,
+                deployment_name=deployment_name)
+        except GoneError:
+            raise InputErrorException('WrongApplication')
+        except ForbiddenError:
+            raise InputErrorException('NotAllowed')
+
     def create(self, args):
         """
             Creates a new application.
